#[macro_use]
extern crate clap;
#[macro_use]
extern crate error_chain;
extern crate koi_core;

mod errors;

use clap::{AppSettings, ArgMatches};
use koi_core::Repo;
use errors::*;

quick_main!(|| -> Result<()> {
    let app = clap_app!(koi =>
        (about  : crate_description!())
        (version: crate_version!())
        (author : crate_authors!())

        (global_settings: &[
            AppSettings::ColoredHelp,
            AppSettings::DeriveDisplayOrder,
            AppSettings::DisableHelpSubcommand,
            AppSettings::GlobalVersion,
            AppSettings::VersionlessSubcommands,
        ])
        (settings: &[
            AppSettings::AllowExternalSubcommands,
            AppSettings::SubcommandRequired,
        ])

        (@subcommand init =>
            (about: "Initialize a new repository")
        )
    ).get_matches();

    match app.subcommand() {
        ("init", Some(matches)) => run_init(matches),
        (external, Some(matches)) => {
            let args = values_t!(matches, "", String)?;
            println!("{:?} {:?}", external, args);

            Ok(())
        },
        (_, None) => {
            Ok(())
        },
    }
});

fn run_init(_: &ArgMatches) -> Result<()> {
    let repo = Repo::new();

    if repo.path.repo_file.exists() {
        Err("repository already exists".into())
    } else {
        Ok(repo.save()?)
    }
}
